.. _forking:

==========================================
Making your own copy (fork) of matplotlib
==========================================

You need to do this only once.  The instructions here are very similar
to the instructions at http://help.github.com/forking/ |emdash| please see
that page for more detail.  We're repeating some of it here just to give the
specifics for the matplotlib_ project, and to suggest some default names.

Set up and configure a github_ account
======================================

If you don't have a github_ account, go to the github_ page, and make one.

You then need to configure your account to allow write access |emdash| see
the ``Generating SSH keys`` help on `github help`_.

Create your own forked copy of matplotlib_
===========================================

#. Log into your github_ account.
#. Go to the matplotlib_ github home at `matplotlib github`_.
#. Click on the *fork* button:

   .. image:: forking_button.png

   Now, after a short pause you should find yourself at the home page
   for your own forked copy of matplotlib_.

.. include:: links.inc
